@@ -1,7 +1,7 @@
 from .kidney import Kidney
 from .monochromator import Monochromator
 from .sample import Sample
-from . import virtualMACS
+from .macsdata import Data
 from .scripting import get_kidney_params
 from .scripting import get_mono_params
 from .scripting import generate_MACS_parts
